@@ -1,12 +1,9 @@
-from ..schema import get_current_schema
+from django_pgschemas.schema import get_current_schema
 
 
 def make_key(key, key_prefix, version):
     """
     Tenant aware function to generate a cache key.
-
-    Constructs the key used by all other methods. Prepends the tenant
-    `schema_name` and `key_prefix'.
     """
     current_schema = get_current_schema()
     return "%s:%s:%s:%s" % (current_schema.schema_name, key_prefix, version, key)
