@@ -1,13 +1,15 @@
 import functools
-import multiprocessing
+from concurrent.futures import ThreadPoolExecutor, as_completed
 
 from django.conf import settings
 from django.core.management import call_command
 from django.core.management.base import BaseCommand, CommandError, OutputWrapper
-from django.db import connection, connections, transaction
+from django.db.utils import ProgrammingError
 
-from ...schema import SchemaDescriptor, activate
-from ...utils import get_clone_reference, get_tenant_model
+from django_pgschemas.routing.info import DomainInfo
+from django_pgschemas.routing.models import get_primary_domain_for_tenant
+from django_pgschemas.schema import Schema, activate
+from django_pgschemas.utils import get_clone_reference, get_tenant_model
 
 
 def run_on_schema(
@@ -18,7 +20,6 @@ def run_on_schema(
     args=None,
     kwargs=None,
     pass_schema_in_kwargs=False,
-    fork_db=False,
 ):
     if args is None:
         args = []
@@ -58,26 +59,30 @@ def run_on_schema(
     command.stdout.style_func = StyleFunc()
     command.stderr.style_func = StyleFunc()
 
-    if fork_db:
-        connections.close_all()
-
     if schema_name in settings.TENANTS:
         domains = settings.TENANTS[schema_name].get("DOMAINS", [])
-        schema = SchemaDescriptor.create(
-            schema_name=schema_name, domain_url=domains[0] if domains else None
+        schema = Schema.create(
+            schema_name=schema_name,
+            routing=DomainInfo(domain=domains[0]) if domains else None,
         )
     elif schema_name == get_clone_reference():
-        schema = SchemaDescriptor.create(schema_name=schema_name)
+        schema = Schema.create(schema_name=schema_name)
     elif (TenantModel := get_tenant_model()) is not None:
-        schema = TenantModel.objects.get(schema_name=schema_name)
+        try:
+            schema = TenantModel.objects.get(schema_name=schema_name)
+            if (domain := get_primary_domain_for_tenant(schema)) is not None:
+                schema.routing = DomainInfo(domain=domain.domain, folder=domain.folder)
+        except ProgrammingError:
+            schema = Schema.create(schema_name=schema_name)
+
     else:
         raise CommandError(f"Unable to find schema {schema_name}!")
 
-    activate(schema)
-
     if pass_schema_in_kwargs:
         kwargs.update({"schema_name": schema_name})
 
+    activate(schema)
+
     if function_name == "special:call_command":
         call_command(command, *args, **kwargs)
     elif function_name == "special:run_from_argv":
@@ -85,10 +90,6 @@ def run_on_schema(
     else:
         getattr(command, function_name)(*args, **kwargs)
 
-    if fork_db:
-        transaction.commit()
-        connection.close()
-
     return schema_name
 
 
@@ -103,16 +104,16 @@ def sequential(
         args=args,
         kwargs=kwargs,
         pass_schema_in_kwargs=pass_schema_in_kwargs,
-        fork_db=False,
     )
+
     for schema in schemas:
         runner(schema)
+
     return schemas
 
 
 def parallel(schemas, command, function_name, args=None, kwargs=None, pass_schema_in_kwargs=False):
     processes = getattr(settings, "PGSCHEMAS_PARALLEL_MAX_PROCESSES", None)
-    pool = multiprocessing.Pool(processes=processes)
     runner = functools.partial(
         run_on_schema,
         executor_codename="parallel",
@@ -121,6 +122,10 @@ def parallel(schemas, command, function_name, args=None, kwargs=None, pass_schem
         args=args,
         kwargs=kwargs,
         pass_schema_in_kwargs=pass_schema_in_kwargs,
-        fork_db=True,
     )
-    return pool.map(runner, schemas)
+
+    with ThreadPoolExecutor(max_workers=processes) as executor:
+        results = {executor.submit(runner, schema) for schema in schemas}
+        as_completed(results)
+
+    return schemas
