@@ -1,17 +1,21 @@
+from typing import Any
+
 from django.db.models.signals import pre_delete
 from django.dispatch import Signal, receiver
 
-from .utils import get_tenant_model, schema_exists
+from django_pgschemas.utils import get_tenant_model, schema_exists
 
 schema_activate = Signal()
 schema_activate.__doc__ = "Sent after a schema has been activated"
 
 dynamic_tenant_needs_sync = Signal()
-dynamic_tenant_needs_sync.__doc__ = "Sent when a schema from a dynamic tenant needs to be synced"
+dynamic_tenant_needs_sync.__doc__ = (
+    "Sent when a schema from a dynamic tenant needs to have migrations applied"
+)
 
 dynamic_tenant_post_sync = Signal()
 dynamic_tenant_post_sync.__doc__ = (
-    "Sent after a tenant has been saved, its schema created and synced"
+    "Sent after a tenant has been saved, its schema created and all migrations applied"
 )
 
 dynamic_tenant_pre_drop = Signal()
@@ -19,7 +23,7 @@ dynamic_tenant_pre_drop.__doc__ = "Sent when a schema from a dynamic tenant is a
 
 
 @receiver(pre_delete)
-def tenant_delete_callback(sender, instance, **kwargs):
+def tenant_delete_callback(sender: Any, instance: Any, **kwargs: object) -> None:
     TenantModel = get_tenant_model()
     if TenantModel is None:
         return
